************
Cuevanalib
************

Cuevanalib is a library to retrieve contents (or its links)
from cuevana.tv_

Before version 0.6, it was part of cuevanalinks_ project,

.. _cuevanalinks: http://packages.python.org/CuevanaLinks

Source code and Issue Tracker: https://bitbucket.org/tin_nqn/cuevanalib/

Dependecies
-----------

``cuevanalib`` scraps the web using PyQuery_ which is based upon lxml_ .

Everything is available via `easy_install` or `pip`

.. _cuevana.tv: http://www.cuevana.tv
.. _PyQuery: http://pyquery.org/
.. _lxml: http://lxml.de/
